#
# spec file for package strigi
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg

Name:           strigi
Version:        0.7.8
Release:        13.15
Summary:        Lightweight and fast desktop search engine
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Other
Url:            http://www.vandenoever.info/software/strigi/
Source0:        http://www.vandenoever.info/software/strigi/%{name}-%{version}.tar.bz2
Source100:      baselibs.conf
# PATCH-FIX-OPENSUSE add_missing_lib.diff adds missing clucene-shared as target link library
Patch1:         add_missing_lib.diff
# PATCH-FIX-UPSTREAM: bug_304439.diff fixes indexing of jpegs with 'wrong' isoSpeedRatings, pending upstream
Patch2:         bug_304439.diff
# PATCH-FIX-UPSTREAM strigi-gcc48.patch -- Add STREAMS_EXPORT to class decl., fixes build with gcc48
Patch3:         strigi-gcc48.patch
BuildRequires:  bison
BuildRequires:  c++_compiler
BuildRequires:  clucene-core-devel
BuildRequires:  cmake
BuildRequires:  dbus-1-x11
BuildRequires:  file-devel
BuildRequires:	libattr-devel
%if 0%{?suse_version} > 1210
BuildRequires:  gamin-devel
%else
BuildRequires:  fam-devel
%endif
BuildRequires:  kde4-filesystem
BuildRequires:  libcppunit-devel
BuildRequires:  libexiv2-devel
BuildRequires:  libexpat-devel
%if %{with ffmpeg}
BuildRequires:  libffmpeg-devel
%endif
BuildRequires:  libbz2-devel
BuildRequires:  libqt4-devel
BuildRequires:  zlib-devel
%if !0%{?sles_version}
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libxml-2.0)
%else
BuildRequires:  dbus-1-devel
BuildRequires:  libxml2-devel
%endif
Requires:       libstreamanalyzer0 = %{version}
Requires:       libstrigi0 = %{version}
Provides:       strigi-ui = 0.5.8
Obsoletes:      strigi-ui < 0.5.8
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
strigi is a very fast crawling, very small memory footprint, no
hammering of the system with pluggable backend desktop search engine.

%package devel
Summary:        Development files for the strigi desktop search engine
Group:          Development/Libraries/C and C++
Requires:       libstreamanalyzer0 = %{version}
Requires:       libstrigi0 = %{version}

%description devel
This package contains development files for the strigi desktop search engine.

%package -n libstrigi0
Summary:        Strigi desktop search engine libraries
Group:          System/Libraries
%requires_ge    libqt4

%description -n libstrigi0
This package contains the strigi desktop search engine libraries.

%package -n libstreamanalyzer0
Summary:        Strigi desktop stream analyzer library
Group:          System/Libraries
%requires_ge    libqt4

%description -n libstreamanalyzer0
This package contains the strigi desktop stream analyzer engine library.

%prep
%setup -q
%if 0%{?suse_version} > 1210
%patch1 -p0
%endif
%patch2 -p1
%patch3 -p1

%build
%cmake_kde4 -d build -- -DENABLE_REGENERATEXSD=off
%make_jobs

%install
%kde4_makeinstall -C build

%post   -n libstrigi0 -p /sbin/ldconfig

%postun -n libstrigi0 -p /sbin/ldconfig

%post   -n libstreamanalyzer0 -p /sbin/ldconfig

%postun -n libstreamanalyzer0 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog
%{_bindir}/deepfind
%{_bindir}/deepgrep
%if 0%{?suse_version} > 1210
%{_bindir}/lucene2indexer
%else
%{_bindir}/luceneindexer
%endif
%{_bindir}/rdfindexer
%{_bindir}/strigiclient
%{_bindir}/strigicmd
%{_bindir}/strigidaemon
%{_bindir}/xmlindexer
%dir %{_libdir}/strigi
%{_libdir}/strigi/strigiea_jpeg.so
%{_libdir}/strigi/strigiea_riff.so
%{_libdir}/strigi/strigiea_digest.so
%if 0%{?suse_version} > 1210
%{_libdir}/strigi/strigiindex_cluceneng.so
%else
%{_libdir}/strigi/strigiindex_clucene.so
%endif
%{_libdir}/strigi/strigila_cpp.so
%{_libdir}/strigi/strigila_deb.so
%{_libdir}/strigi/strigila_namespaceharvester.so
%{_libdir}/strigi/strigila_txt.so
%{_libdir}/strigi/strigila_xpm.so
%{_libdir}/strigi/strigita_au.so
%{_libdir}/strigi/strigita_avi.so
%{_libdir}/strigi/strigita_dds.so
%{_libdir}/strigi/strigita_gif.so
%{_libdir}/strigi/strigita_ico.so
%{_libdir}/strigi/strigita_pcx.so
%{_libdir}/strigi/strigita_rgb.so
%{_libdir}/strigi/strigita_sid.so
%{_libdir}/strigi/strigita_wav.so
%{_libdir}/strigi/strigita_xbm.so
%if %{with ffmpeg}
%{_libdir}/strigi/strigiea_ffmpeg.so
%endif
%{_datadir}/dbus-1/services/org.freedesktop.xesam.searcher.service
%{_datadir}/dbus-1/services/vandenoever.strigi.service
%{_datadir}/strigi/

%files devel
%defattr(-,root,root,-)
%{_includedir}/strigi/
%{_libdir}/libsearchclient.so
%{_libdir}/libstreamanalyzer.so
%{_libdir}/libstreams.so
%{_libdir}/libstrigihtmlgui.so
%{_libdir}/libstrigiqtdbusclient.so
%dir %{_libdir}/cmake/LibSearchClient/
%{_libdir}/cmake/LibSearchClient/LibSearchClientConfig.cmake
%dir %{_libdir}/cmake/LibStreamAnalyzer/
%{_libdir}/cmake/LibStreamAnalyzer/LibStreamAnalyzerConfig.cmake
%{_libdir}/cmake/LibStreamAnalyzer/LibStreamAnalyzerConfigVersion.cmake
%dir %{_libdir}/cmake/LibStreams/
%{_libdir}/cmake/LibStreams/LibStreamsConfig.cmake
%{_libdir}/cmake/LibStreams/LibStreamsConfigVersion.cmake
%{_libdir}/cmake/LibStreams/LibStreamsTargets-release.cmake
%{_libdir}/cmake/LibStreams/LibStreamsTargets.cmake
%{_libdir}/pkgconfig/libstreamanalyzer.pc
%{_libdir}/pkgconfig/libstreams.pc
%dir %{_libdir}/cmake/Strigi/
%{_libdir}/cmake/Strigi/StrigiConfig.cmake
%{_libdir}/cmake/Strigi/StrigiConfigVersion.cmake

%files -n libstrigi0
%defattr(-,root,root,-)
%{_libdir}/libsearchclient.so.0*
%{_libdir}/libstrigihtmlgui.so.0*
%{_libdir}/libstrigiqtdbusclient.so.0*

%files -n libstreamanalyzer0
%defattr(-,root,root,-)
%{_libdir}/libstreamanalyzer.so.0*
%{_libdir}/libstreams.so.0*

%changelog
* Tue Aug 12 2014 hrvoje.senjan@gmail.com
- Move away from kde4-filesystem macros: strigi doesn't use kdelibs4
  buildsystem
* Thu Jul 31 2014 wbauer@tmo.at
- Add libstreamanalyzer0 to baselibs.conf to make libkde4-32bit
  installable, it requires libstreamanalyzer0.so.0()(32bit) which
  is not provided by libstrigi0-32bit any more
* Sat May 24 2014 tittiatcoke@gmail.com
- Split out libstreamanalyzer to reduce dependencies as that we
  have to build kdelibs4 with support for this library to get
  some metadata during kio actions (bnc#879506)
* Mon Apr 28 2014 dmueller@suse.com
- remove dependency on java-devel
* Tue Jun 18 2013 hrvoje.senjan@gmail.com
- Added strigi-gcc48.patch which adds STREAMS_EXPORT to class decl.,
  fixes build with gcc48
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Feb  6 2013 hrvoje.senjan@gmail.com
- Update to version 0.7.8
  * Fix xpm and xbm index
  * Extract tracknumber and track count from a value like "03/16"
  * Fixed indexing of m3u files
  * Fix FLAC Files: Remove addtional 'db' in replaygain
  * Fix: flac analizer was importing only one artist tag
  * Fix: non numeric genres in id3 v2 mp3 are ignored
  * Fix parsing of genre field in id3v2 tags
  * Change: TPE2 tag it's used as nmm:albumArtist instead as
    nmm:performer in ID3 analyzer
  * Change: added support to TRACKTOTAL tag as an equivalent to
    TRACKCOUNT in FLAC analyzer
  * C++11 fixes
  * Let the strigi ffmpeg plugin compile on modern ffmpeg versions
  * Remove dependency on boost
  * Use GNUInstallDirs in order to install into lib64
    automatically
  * Install a version file for the CMake config module
  * Allow the Strigi submodules to be installed in custom prefixes
- Drop git.diff patch, all aplied upstream
- Dropped boost-devel BuildRequires as per upstream changes
* Sun Nov 25 2012 cgiboudeaux@gmx.com
- Fix the SLES build: Replace BuildRequires:pkgconfig(...)
* Tue Oct 16 2012 coolo@suse.com
- add explicit buildrequire on libbz2-devel
* Tue Aug 14 2012 hrvoje.senjan@gmail.com
- Add git.diff patch, which syncs strigi to current git snapshot.
  * Adding support to TRACKTOTAL tag equivalent to TRACKCOUNT tag
  * Use TPE2 tag as nmm:albumArtist in id3 tags
  * Fix: non numeric genres in id3 v2 mp3 are ignored
  * Fix: only the last performer is added when there is more than one artist tag in a flac file
  * Fix FLAC files - remove 'db' in replaygain
  * Fix m3u playlist indexing
  * Extract tracknumber and track count from a value like "03/16"
  * Fix xpm and xbm for strigi analysis
- Add fix for jpegendanalyzer not able to index files with isoSpeedRatings value
- Drop obsolete strigi-missing-decl.patch, now contained in git.diff
* Sun May 27 2012 Manfred.Tremmel@iiv.de
- build against ffmpeg_oldabi, because ffmpeg calls are outdated
* Thu Mar 15 2012 aj@suse.de
- Fix build: Always include unistd.h for sleep declaration.
* Tue Mar  6 2012 stefan.bruens@rwth-aachen.de
-  update to 0.7.7:
  - Many nepomuk field name fixes
  - More accurate file format check for tar files
  - Better checking of bounds in OLE files.
  - Increase performance of default file input stream.
  - Check for surrogate pairs in UTF-8 strings.
  - Improve ID3 analyzer: skip zero padding before mp3 stream to
    handle typical LAME output, implement unsynchronization flag
    handling
  - Properly finish child indexing in all analyzers.
* Fri Jan 20 2012 toddrme2178@gmail.com
- For Factory switched the file monitoring backend from fam to the upstream-recommended gamin
  this is not available in earlier versions of openSUSE
* Sat Dec  3 2011 tittiatcoke@gmail.com
- Add a patch to make strigi build with the new clucene version
  in Factory.
* Thu Nov 24 2011 wstephenson@suse.com
- Update to 0.7.6
  - Better performance reading PDF streams of unknown length
  - More accurate metadata indexing particularly of media files
* Sun Oct  2 2011 reddwarf@opensuse.org
- Cleaned up spec file formatting
* Wed Aug 10 2011 reddwarf@opensuse.org
- Optionally enable ffmpeg indexing support.
* Tue Jul 26 2011 asterios.dramis@gmail.com
- Update to version 0.7.5:
  * Synchronize the modules. In 0.7.4, the modules were not synchronized.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Removed openssl-devel from BuildRequires: (not needed).
  * Added dbus-1-devel, dbus-1-x11, java-devel, libexpat-devel and zlib-devel
    in BuildRequires:.
  * Added description for the patch based on openSUSE Patches Guidelines.
  * Updates in Summary:, %%description and Group entries.
  * Compile the package out of source.
  * Minor other updates.
* Fri Jan 28 2011 remur@gmx.net
- Check file size of ole compound documents (bko#251701)
  * Dolphin crashes when hovering a MSI file
* Tue Jan 18 2011 wstephenson@novell.com
- Update to newer snapshot
  * Fix double delete in libstreamindexer (bko#257944)
* Tue Dec 14 2010 toddrme2178@gmail.com
- Add optional dependency
  * FAM - Support for efficient file change monitoring system
* Tue Dec 14 2010 wstephenson@novell.com
- rpmlint fixes:
  * Remove obsolete versions
  * Correct RPM groups
* Fri Nov  5 2010 tittiatcoke@gmail.com
- update to version 0.7.3
  * Always read the image size of the JPEG from the header (bko#246854)
  * Add support for parsing XESAM xml-language
* Thu Aug 26 2010 tittiatcoke@gmail.com
- Update to a newer snapshot. This snapshot is able to work with
  the new clucene version.
* Fri Jul 30 2010 tittiatcoke@gmail.com
- Update to a newer snapshot
* Thu Feb 11 2010 tittiatcoke@gmail.com
- update to 0.7.2
  - Improve cpp analyzer speed and output
  - Fix crash due to deep nesting of calls in pdf analyzer
  - Fix iconv use on Mac OS X
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Jan 14 2010 tittiatcoke@gmail.com
- update to 0.7.1
  - Support more fields from ODF documents
  - Improved skipping behavior on streams for large files.
  - Added album art support.
  - Added support for ID3v1 tags.
  - Added MP3 stream metadata extraction, UTF-16 support in tags.
  - Extended the range of metadata extracted by ID3 analyzer.
  - Added a FLAC audio file analyzer.
  - Significantly unbreak the PDF analyzer.
  - Fix scanning trees where permissions are insufficient to read some parts
  - Check for multithreaded version of libxml2
  - Require newer CLucene version (0.9.21)
* Sun Aug  2 2009 beineri@opensuse.org
- update to 0.7.0:
  * Change to Nepomuk ontologies
  * Set file property for embedded ar streams. This fixes the
    opening of these streams in archivereader.
  * Instead of reading each .rdf file at once in memory and then
    parse it, use the libxml2 I/O API to read chunks of the file
    when requested.
  * The attribute value is not '\0' terminated but has a pointer
    to the end of the string. In addition, string comparison was
    sped up by first comparing the string length.
* Sun May 17 2009 beineri@opensuse.org
- update to 0.6.5:
  * now allows path that start with protocol:/* like 'file:///'
  * Add a new function AnalysisResult::child().
  * Adjust to the new library naming scheme in iconv-1.12
  * Implemented missing addTriplet method
  * Rewrite the implementation of ArchiveReader. The new implemen-
    tation is more effient in listing contents of directories.
* Wed May 13 2009 dmueller@suse.de
- add versioned dependency
* Mon Feb  2 2009 stbinner@suse.de
- update to 0.6.4:
  - Path fixes to the build system the benefit of windows users
  - Clean up of class ArchiveReader
  - Support for LZMA compressed streams in archives, notably .deb & .rpm
  - Remove preceding ./ from file path in tar archives.
  - Make parsing ar and deb files easier to abort: useful in e.g. Dolphin
  - Better method of removing deleted file from the CLucene
  - Do not tokenize the URL in the index to improve polling speed
  - Fix the bz2 header check: more bz2 archives are recognized
  - Fix infinite loop on parsing SGI image files
  - Fix reading of zip files without central directory.
* Tue Jan 13 2009 dmueller@suse.de
- update to 0.6.3:
  - Move Strigi::DirLister in archivereader.h to ArchiveReader::DirLister.
  - Change type of EntryInfo.mtime from 'unsigned' to time_t.
  - The spec of SDF files was found and used to implement a more precise syntax check for the header of SDF files.
  - Fix memory corruption bug in ArchiveReader.
  - Change type of ontology entry 'exposureTime' to string.
  - Add a default rule to find mail box directories with pattern '.*.directory'.
  - Add '$HOME/.kde4' to the directories that are indexed by default.
  - Simplify matching of file paths in the rules for including
  - Fix a big performance problem:  Whenever a directory mtime changed, all files inside the directory were re-indexed.
  - Fix bug where a gz archive that contains a file that is identical to the
  original archive is indexed over and over. The depth of nested files that are indexed is now limited to 127.
* Fri Jan  9 2009 dmueller@suse.de
- update to 0.6.2:
  - Better support for nice IO priorities on Linux (Sebastian Trueg)
  - Compile with development version of CLucene (Ben van Klinken)
  - Explicitly use 'unsigned char' or 'signed char' instead of 'char'
  - Many CMake cleanups (Alexander Neundorf)
  - 6.5x speedup of C++ comment analyzer (Jakub Stachowski)
  - Various stability fixes (Jos van den Oever, Sebastian Trueg)
  - Support for ePub format (Jakub Stachowski)
  - Handle RIFF file with unspecified size for the RIFF packet. (Jos van den Oever)
* Tue Oct 21 2008 dmueller@suse.de
- stricter requirements
* Mon Sep  8 2008 dmueller@suse.de
- fix build for old distros
* Wed Aug 27 2008 dmueller@suse.de
- add missing versioning requires for libstrigi0
* Tue Jul 29 2008 coolo@suse.de
- obsolete old name
* Mon Jul 28 2008 wstephenson@suse.de
- Patch to trunk
  * Install indexpluginloader.h, now needed by Nepomuk
* Mon Jul 21 2008 stbinner@suse.de
- update to 0.5.11:
  - Make sure the app can handle environments where HOME is not defined.
  - Make the zip analyzer check more often if it should stop analyzing.
  - Make the analyzer respect a configuration that only wants part of
  the stream to be analyzed.
  - Add an analyzer for Windows self-extracting zip archives.
  - Ask the analyzerconfiguration if we should continue and put a cap
  on the maximum length of stream we read
  - Log parse errors in the analysisresult.
  - Several bugfixes
* Sun Jun 22 2008 dmueller@suse.de
- update to 0.5.10:
  * Improved Xesam support. strigidaemon can now be queried with the client from
    the Xesam test suite.
  * Fix a bug in subinputstream.
    Under certain circumstances the function read() of the internal stream could
    be called with max < min. read() specifies that in such cases, there is no
    limit on the number of bytes that may be read. This would cause
    SubInputStream to malfunction because it would allow too much of the internal
    stream to be read.
  * Reenable a number of endanalyzers.
    By accident, the analyzers for .tar and .gz files were disabled in the
    previous release. Now they are re-enabled.
* Tue Apr 29 2008 dmueller@suse.de
- update to 0.5.9:
  * Fix bug that would severely bloat the strigi index.
  * Improve latency when calling strigi to stop.
  * Better (but not yet complete) Xesam support
* Sun Apr 13 2008 dmueller@suse.de
- fix build against cmake 2.6
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb 20 2008 stbinner@suse.de
- update to 0.5.8, some changes include:
  * Improve quiting latency of the most important analyzers. Now
    Strigi reacts more quickly when you tell it to stop indexing.
  * Add a tool to analyze the analyzer latency profile and find
    analyzers that have a high latency.
  * Bring field names in line with the Xesam ontology.
  * New analyzers for avi, wav, dds, rgb, sid and ico file types.
  * Fix deepgrep (finally working again since 0.5.2) and extend
    the number of fields deepgrep searches in.
  * 'strigicmd listFiles' now can be used to retrieve all files/dir
    indexed under a certain path
* Sat Dec 15 2007 stbinner@suse.de
- fix build requires
* Thu Dec  6 2007 dmueller@suse.de
- drop strigi-ui, split libstrigi0
* Sun Oct 28 2007 stbinner@suse.de
- update to 0.5.7:
  * use plugins instead of shared libraries for the indexer backends
  * lots of bugfixes and cleanups
  * allow backends to be used in RAM by using ':memory:' as index name
* Mon Oct  8 2007 dmueller@suse.de
- update to 0.5.6:
  * Added Xesam User Language parser.
  * Replaced .ini-based ontology parser with RDF/XML one.
  * Updated strigicmd: now it's possible to perform searches formulated
  following xesam userlanguage specifications.
  * change IndexReader::getFiles to IndexReader::getChildren.
  * removed IndexReader::documentId and IndexReader::mTime.
  * loads of build issues fixed
  * added a script that helps you to find the patch that broke a unit test
  * add fieldname for document content per the Xesam standard.
* Fri Aug 31 2007 dmueller@suse.de
- fix compilation when gcc43 is used
* Tue Aug  7 2007 dmueller@suse.de
- use the release tarball (0.5.5)
  * no changes
* Mon Aug  6 2007 dmueller@suse.de
- update to current SVN:
  * fixes an include bug by rearranging the way the
    strigiconfig.h include is installed
* Thu Aug  2 2007 dmueller@suse.de
- fix build against gcc 4.3
* Thu Jul 26 2007 dmueller@suse.de
- update to 0.5.4:
  * improved xesam support
  * various stability fixes
* Wed Jul 18 2007 dmueller@suse.de
- update to 0.5.2:
  * xesam support
* Mon Jun 25 2007 stbinner@suse.de
- update to current SVN
* Thu May 31 2007 dmueller@suse.de
- update to current SVN:
  * xesam support
  * many crash fixes
* Wed May 23 2007 stbinner@suse.de
- added missing run_ldconfig calls
* Fri May 11 2007 dmueller@suse.de
- add branch diff
  * crash fixes
* Wed May  2 2007 dmueller@suse.de
- update to current SVN:
  * pkgconfig fixes
  * include guards for headers
* Tue Apr 24 2007 dmueller@suse.de
- update to 0.5.0:
  * cmd line interface
  * pkgconfig module
  * more modules, bugfixes
* Tue Apr 10 2007 stbinner@suse.de
- Update to current SVN
* Sun Apr  1 2007 dmueller@suse.de
- Update to current SVN
* Mon Mar 26 2007 dmueller@suse.de
- Update to current SVN
* Wed Mar 21 2007 dmueller@suse.de
- split package into useful subpackages
* Tue Mar 20 2007 dmueller@suse.de
- update to current SVN to add xbm reader
* Mon Mar 19 2007 dmueller@suse.de
- update to current SVN to follow API change
* Thu Mar 15 2007 dmueller@suse.de
- udpate to current SVN to follow API refactoring
* Tue Mar 13 2007 dmueller@suse.de
- update to current SVN to fix compilation of header files
* Sun Mar 11 2007 dmueller@suse.de
- update to current SVN to install needed libraries
* Sat Mar 10 2007 dmueller@suse.de
- build against clucene
* Thu Mar  8 2007 dmueller@suse.de
- update to current SVN
* Wed Mar  7 2007 dmueller@suse.de
- Initial package (SVN of 20070228)
